bisect_left

Function bisect_left 

pub fn bisect_left<T>(a: &[T], x: &T) -> usize
where T: Ord,
Return the index where x should be inserted in a, assuming a is sorted.

The return value i is such that all e in a[..i] have e < x, and all e in a[i..] have e >= x.

  • If a contains x, a.insert(i, x) will insert just before the leftmost x.